@@ -1,19 +1,18 @@
 # flake8: noqa
+# type: ignore
 __author__ = "Akio Taniguchi"
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 
 # submodules
+from . import common
 from . import dataarray
-from . import field
+from . import dataset
 from . import typing
 from . import utils
 
 
 # aliases
 from .dataarray import *
+from .dataset import *
 from .typing import *
-
-
-# for sphinx docs
-__all__ = dir()
